@@ -48,7 +48,7 @@ prepare_results.pca <- function(obj) {
   tmp <- tmp %>% mutate(varname = rownames(tmp),
                         Type = "Active", Class = "Quantitative") %>%
     gather(Axis, Contrib, starts_with("Axis")) %>%
-    mutate(Axis = gsub("^Axis([0-9]+)\\(%\\)$", "\\1", Axis),
+    mutate(Axis = gsub("^Axis([0-9]+)$", "\\1", Axis),
            Contrib = round(Contrib, 3))
     
   vars <- vars %>% left_join(tmp, by = c("varname", "Type", "Class", "Axis"))
@@ -86,7 +86,7 @@ prepare_results.pca <- function(obj) {
   tmp <- inertia$row.abs
   tmp <- tmp %>% mutate(Name = rownames(tmp), Type = "Active") %>%
     gather(Axis, Contrib, starts_with("Axis")) %>%
-    mutate(Axis = gsub("^Axis([0-9]+)\\(%\\)$", "\\1", Axis),
+    mutate(Axis = gsub("^Axis([0-9]+)$", "\\1", Axis),
            Contrib = round(Contrib, 3))
   
   ind <- ind %>% left_join(tmp, by = c("Name", "Type", "Axis"))
